################
# Ex3 solution #
################
data(data.examples)
# 1) exdes: stratified, two-stage, cluster sampling (no fpc available)
exdes <- e.svydesign(data=example, ids=~towcod+famcod, strata=~SUPERSTRATUM, weights=~weight)


# 2) Calibration constraints:
#    (i)  population counts by sex and age5c
#    (ii) population counts by age5c and regcod
#
#    A GLOBAL calibration model for (i) and (ii) would be:
#    - calmodel = ~sex:age5c + regcod:age5c - 1
#    that is, equivalently:
#    - calmodel = ~(sex + regcod):age5c - 1
#
#    However, since age5c is a common factor variable interacting with all the
#    other variables appearing inside the GLOBAL calmodel formula, the
#    calibration task is FACTORIZABLE.
#
#    Indeed, constraints (i) and (ii) may be rephrased as:
#    "population counts by sex AND population counts by regcod, WITHIN age5c domains"
#
#    This yields the PARTITIONED calibration model specification:
#    - calmodel  = ~ sex + regcod - 1
#    - partition = ~age5c


# 3) Build the template:
expop<-pop.template(data=exdes, calmodel= ~ sex + regcod - 1, partition= ~age5c)


# 4) Check that it is ok:
expop
pop.desc(expop)

# IMPORTANT NOTE: Region 6 has disappeared from expop, to avoid collinearity.
#                 In fact, its population counts can be deduced from the other ones.


# 5) Import population aggregates from external source (if needed, change the
#    path to the files):
sex_age5c <- read.table(file="sex_age5c.csv", header=TRUE, sep=";", dec= ".")
sex_age5c

regcod_age5c <- read.table(file="regcod_age5c.csv", header=TRUE, sep=";", dec=".")
regcod_age5c

# BEWARE: regcod_age5c has also Region 6, which we do NOT need.

# The description obtained by invoking pop.desc(expop) tells us that:
# - columns *2-3* of expop must store *Counts of sex* corresponding to *levels: "f", "m"*
# - columns *4-5* of expop must store *Counts of regcod* corresponding to *levels: "7", "10"*

# Therefore, fill expop accordingly:
# - counts of sex
expop[, 2:3] <- sex_age5c[, 2:3]
# - counts of regcod
expop[, 4:5] <- regcod_age5c[, 3:4]   # Note that the RHS avoids Region 6

# print filled template:
expop


# 6) Calibrate exdes following the stated requirements:
#    First, get suggested bounds for range-restricted calibration:
bounds.h<-bounds.hint(design=exdes, df.population=expop)

#    Then, execute the calibration task:
#    6.1)
excal.lin<-e.calibrate(exdes, expop, calfun="linear", bounds=bounds.h, aggregate.stage=2)

#    6.2)
excal.rak<-e.calibrate(exdes, expop, calfun="raking", bounds=bounds.h, aggregate.stage=2)

#    6.3)
excal.log<-e.calibrate(exdes, expop, calfun="logit", bounds=bounds.h, aggregate.stage=2)


# 7) Compute the range of the obtained g-weights:
g.range(excal.lin)
g.range(excal.rak)
g.range(excal.log)

#    And compare calibration weights summaries:
#    - initial
summary(weights(exdes))
#    - calibrated
summary(weights(excal.lin))
summary(weights(excal.rak))
summary(weights(excal.log))

#    All three sets of calibration weights are so close to each other, that I
#    see no reasons to express a preference.
