################
# Ex3 solution #
################
# Import Ilocos.csv. May use the GUI of ReGenesees or the command line (change
# the path to the file if needed)
ilo <- read.table(file="Ilocos.csv", header=TRUE, sep=";", na.strings=NA, quote="\"", dec=".", strip.white=TRUE, comment.char="")

# Re-order the levels of family size classes (default alphanumeric ordering
# would place '10+' as second level, which is bothering...)
table(ilo$famsize10c)
ilo$famsize10c <- factor(ilo$famsize10c, levels = c(1:9,"10+"))
table(ilo$famsize10c)

# Define ilodes:
ilodes <- e.svydesign(data=ilo, ids=~id, strata=~stratum, weights=~weight)
ilodes

##############
# Exercise 1 #
##############
# 1) Total household income, with CV% and 95% confidence interval
a1 <- svystatTM(ilodes, y=~household.income, vartype="cvpct", conf.int=TRUE)
a1

# 2) Average household income, with CV% and 95% confidence interval
a2 <- svystatTM(ilodes, y=~household.income, estimator = "Mean", vartype="cvpct", conf.int=TRUE)
a2

# 3) Median household income, with CV% and 95% confidence interval
#    NOTE: Confidence intervals are *always* provided for quantiles, so no
#          conf.int=TRUE
a3 <- svystatQ(ilodes, y=~household.income, probs = 0.5, vartype="cvpct")
a3

# 4) Average household income by family size classes
a4 <- svystatTM(ilodes, y=~household.income, by=~famsize10c, estimator = "Mean")
a4

# 5) Median household income by family size classes
a5 <- svystatQ(ilodes, y=~household.income, probs = 0.5, by=~famsize10c)
a5

# 6) Share of total household income by classes of family size
a6 <- svystatS(ilodes, y=~household.income, classes=~famsize10c)
a6


##############
# Exercise 2 #
##############
# 7) Total number of households
a7 <- svystatTM(ilodes, y=~ones)
a7

# 8) Average household size (i.e. mean number of individual per household)
## Can use svystatTM
a8 <- svystatTM(ilodes, y=~family.size, estimator = "Mean")
a8
## Or equivalently, svystatR
a8 <- svystatR(ilodes, num=~family.size, den=~ones)
a8

# 9) Total number of households by province
a9 <- svystatTM(ilodes, y=~province)
a9

# 10) Proportion of households by family size classes
a10 <- svystatTM(ilodes, y=~famsize10c, estimator = "Mean")
a10

# 11) Total number of individuals
a11 <- svystatTM(ilodes, y=~family.size)
a11

# 12) Total number of individuals by family size classes
a12 <- svystatTM(ilodes, y=~family.size, by=~famsize10c)
a12

# 13) Proportion of individuals by family size classes
a13 <- svystatS(ilodes, y=~family.size, classes=~famsize10c)
a13
